==> ui-framework-4.15.21-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractSearchBoxExamplesMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractSearchBoxExamplesMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _7_1_1880541287 _7_1_1880541287;
	public SearchBoxExamplesMold._7_1_1880541287. _8_2_1894140202 _8_2_1894140202;
	public SearchBoxExamplesMold._7_1_1880541287._8_2_1894140202. _9_3_0308355687 _9_3_0308355687;
	public SearchBoxExamplesMold._7_1_1880541287._8_2_1894140202. _10_3_0687123240 _10_3_0687123240;
	public SearchBoxExamplesMold._7_1_1880541287._8_2_1894140202._10_3_0687123240. SearchBox1 searchBox1;
	public SearchBoxExamplesMold._7_1_1880541287._8_2_1894140202._10_3_0687123240. List1 list1;
	public SearchBoxExamplesMold._7_1_1880541287._8_2_1894140202. _19_3_1730637905 _19_3_1730637905;
	public SearchBoxExamplesMold._7_1_1880541287._8_2_1894140202._19_3_1730637905. _19_11_1716687082 _19_11_1716687082;

    public AbstractSearchBoxExamplesMold(B box) {
        super(box);
        id("searchBoxExamplesMold");
    }

    @Override
	public void init() {
		super.init();
		if (_7_1_1880541287 == null) _7_1_1880541287 = register(new _7_1_1880541287(box()).<_7_1_1880541287>id("a1626560507").owner(AbstractSearchBoxExamplesMold.this));
		if (_7_1_1880541287 != null) _8_2_1894140202 = _7_1_1880541287._8_2_1894140202;
		if (_8_2_1894140202 != null) _9_3_0308355687 = _7_1_1880541287._8_2_1894140202._9_3_0308355687;
		if (_8_2_1894140202 != null) _10_3_0687123240 = _7_1_1880541287._8_2_1894140202._10_3_0687123240;
		if (_10_3_0687123240 != null) searchBox1 = _7_1_1880541287._8_2_1894140202._10_3_0687123240.searchBox1;
		if (_10_3_0687123240 != null) list1 = _7_1_1880541287._8_2_1894140202._10_3_0687123240.list1;
		if (_8_2_1894140202 != null) _19_3_1730637905 = _7_1_1880541287._8_2_1894140202._19_3_1730637905;
		if (_19_3_1730637905 != null) _19_11_1716687082 = _7_1_1880541287._8_2_1894140202._19_3_1730637905._19_11_1716687082;



		if (searchBox1 != null) searchBox1.bindTo(list1);
	}

    @Override
    public void remove() {
        super.remove();
	    if (_7_1_1880541287 != null) _7_1_1880541287.unregister();
	}

	public class _7_1_1880541287 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public SearchBoxExamplesMold._7_1_1880541287. _8_2_1894140202 _8_2_1894140202;

		public _7_1_1880541287(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_8_2_1894140202 == null) _8_2_1894140202 = register(new _8_2_1894140202(box()).<_8_2_1894140202>id("a1991660970").owner(AbstractSearchBoxExamplesMold.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_8_2_1894140202 != null) _8_2_1894140202.unregister();
		}

		public class _8_2_1894140202 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public SearchBoxExamplesMold._7_1_1880541287._8_2_1894140202. _9_3_0308355687 _9_3_0308355687;
			public SearchBoxExamplesMold._7_1_1880541287._8_2_1894140202. _10_3_0687123240 _10_3_0687123240;
			public SearchBoxExamplesMold._7_1_1880541287._8_2_1894140202. _19_3_1730637905 _19_3_1730637905;

			public _8_2_1894140202(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_9_3_0308355687 == null) _9_3_0308355687 = register(new _9_3_0308355687(box()).<_9_3_0308355687>id("a_719134706").owner(AbstractSearchBoxExamplesMold.this));
				if (_10_3_0687123240 == null) _10_3_0687123240 = register(new _10_3_0687123240(box()).<_10_3_0687123240>id("a_201890402").owner(AbstractSearchBoxExamplesMold.this));
				if (_19_3_1730637905 == null) _19_3_1730637905 = register(new _19_3_1730637905(box()).<_19_3_1730637905>id("a_63431909").owner(AbstractSearchBoxExamplesMold.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_9_3_0308355687 != null) _9_3_0308355687.unregister();
				if (_10_3_0687123240 != null) _10_3_0687123240.unregister();
				if (_19_3_1730637905 != null) _19_3_1730637905.unregister();
			}

			public class _9_3_0308355687 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _9_3_0308355687(B box) {
					super(box);
					_value("No facets");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}

			public class _10_3_0687123240 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public SearchBoxExamplesMold._7_1_1880541287._8_2_1894140202._10_3_0687123240. SearchBox1 searchBox1;
				public SearchBoxExamplesMold._7_1_1880541287._8_2_1894140202._10_3_0687123240. List1 list1;

				public _10_3_0687123240(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (searchBox1 == null) searchBox1 = register(new SearchBox1(box()).<SearchBox1>id("a_1182136866").owner(AbstractSearchBoxExamplesMold.this));
					if (list1 == null) list1 = register(new List1(box()).<List1>id("a819653891").owner(AbstractSearchBoxExamplesMold.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (searchBox1 != null) searchBox1.unregister();
					if (list1 != null) list1.unregister();
				}

				public class SearchBox1 extends io.intino.alexandria.ui.displays.components.SearchBox<io.intino.alexandria.ui.displays.notifiers.SearchBoxNotifier, B>  {

					public SearchBox1(B box) {
						super(box);
						label("female population");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}

				public class List1 extends io.intino.alexandria.ui.displays.components.List<B, SearchBox1Mold, io.intino.alexandria.ui.documentation.Person>  {

					public List1(B box) {
						super(box);

						_pageSize(20);
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}

					public SearchBox1Mold create(io.intino.alexandria.ui.documentation.Person element) {
						SearchBox1Mold result = new SearchBox1Mold((UiFrameworkBox)box());
						result.id(java.util.UUID.randomUUID().toString());
						result.item(element);
						return result;
					}
				}
			}

			public class _19_3_1730637905 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public SearchBoxExamplesMold._7_1_1880541287._8_2_1894140202._19_3_1730637905. _19_11_1716687082 _19_11_1716687082;

				public _19_3_1730637905(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_19_11_1716687082 == null) _19_11_1716687082 = register(new _19_11_1716687082(box()).<_19_11_1716687082>id("a_1325868256").owner(AbstractSearchBoxExamplesMold.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (_19_11_1716687082 != null) _19_11_1716687082.unregister();
				}

				public class _19_11_1716687082 extends io.intino.alexandria.ui.displays.components.TextCode<io.intino.alexandria.ui.displays.notifiers.TextCodeNotifier, B>  {

					public _19_11_1716687082(B box) {
						super(box);
						_value("SearchBox(collections=list,placeholder=\"filter elements...\") searchBoxList(itemClass=\"io.intino.alexandria.ui.documentation.Person\") list<br/>&nbsp;&nbsp;&nbsp;&nbsp;Mold > Item(height=60px,width=30%) sortingMold<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Text firstName<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Block(layout=Horizontal, spacing=DP16)<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Text(format=description) gender<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Text(format=description) age as Labeled(\"age\")");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}
			}
		}
	}
}

==> ui-framework-4.28.12-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractSearchBoxExamplesMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractSearchBoxExamplesMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _7_1_1484719442 _7_1_1484719442;
	public SearchBoxExamplesMold._7_1_1484719442. _8_2_0351473557 _8_2_0351473557;
	public SearchBoxExamplesMold._7_1_1484719442._8_2_0351473557. _9_3_0308355687 _9_3_0308355687;
	public SearchBoxExamplesMold._7_1_1484719442._8_2_0351473557. _10_3_0687123240 _10_3_0687123240;
	public SearchBoxExamplesMold._7_1_1484719442._8_2_0351473557._10_3_0687123240. SearchBox1 searchBox1;
	public SearchBoxExamplesMold._7_1_1484719442._8_2_0351473557._10_3_0687123240. List1 list1;
	public SearchBoxExamplesMold._7_1_1484719442._8_2_0351473557. _19_3_1730637905 _19_3_1730637905;
	public SearchBoxExamplesMold._7_1_1484719442._8_2_0351473557._19_3_1730637905. _19_11_1716687082 _19_11_1716687082;

	public AbstractSearchBoxExamplesMold(B box) {
		super(box);
		id("searchBoxExamplesMold");
	}

	@Override
	public void init() {
		super.init();
		if (_7_1_1484719442 == null) _7_1_1484719442 = register(new _7_1_1484719442(box()).<_7_1_1484719442>id("a_423780945").owner(AbstractSearchBoxExamplesMold.this));
		if (_7_1_1484719442 != null) _8_2_0351473557 = _7_1_1484719442._8_2_0351473557;
		if (_8_2_0351473557 != null) _9_3_0308355687 = _7_1_1484719442._8_2_0351473557._9_3_0308355687;
		if (_8_2_0351473557 != null) _10_3_0687123240 = _7_1_1484719442._8_2_0351473557._10_3_0687123240;
		if (_10_3_0687123240 != null) searchBox1 = _7_1_1484719442._8_2_0351473557._10_3_0687123240.searchBox1;
		if (_10_3_0687123240 != null) list1 = _7_1_1484719442._8_2_0351473557._10_3_0687123240.list1;
		if (_8_2_0351473557 != null) _19_3_1730637905 = _7_1_1484719442._8_2_0351473557._19_3_1730637905;
		if (_19_3_1730637905 != null) _19_11_1716687082 = _7_1_1484719442._8_2_0351473557._19_3_1730637905._19_11_1716687082;



		if (searchBox1 != null) searchBox1.bindTo(list1);
	}

	@Override
	public void remove() {
		super.remove();
		if (_7_1_1484719442 != null) _7_1_1484719442.unregister();
	}

	public class _7_1_1484719442 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public SearchBoxExamplesMold._7_1_1484719442. _8_2_0351473557 _8_2_0351473557;

		public _7_1_1484719442(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_8_2_0351473557 == null) _8_2_0351473557 = register(new _8_2_0351473557(box()).<_8_2_0351473557>id("a1680444839").owner(AbstractSearchBoxExamplesMold.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (_8_2_0351473557 != null) _8_2_0351473557.unregister();
		}

		public class _8_2_0351473557 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public SearchBoxExamplesMold._7_1_1484719442._8_2_0351473557. _9_3_0308355687 _9_3_0308355687;
			public SearchBoxExamplesMold._7_1_1484719442._8_2_0351473557. _10_3_0687123240 _10_3_0687123240;
			public SearchBoxExamplesMold._7_1_1484719442._8_2_0351473557. _19_3_1730637905 _19_3_1730637905;

			public _8_2_0351473557(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_9_3_0308355687 == null) _9_3_0308355687 = register(new _9_3_0308355687(box()).<_9_3_0308355687>id("a_719134706").owner(AbstractSearchBoxExamplesMold.this));
				if (_10_3_0687123240 == null) _10_3_0687123240 = register(new _10_3_0687123240(box()).<_10_3_0687123240>id("a_201890402").owner(AbstractSearchBoxExamplesMold.this));
				if (_19_3_1730637905 == null) _19_3_1730637905 = register(new _19_3_1730637905(box()).<_19_3_1730637905>id("a_63431909").owner(AbstractSearchBoxExamplesMold.this));
			}

			@Override
			public void unregister() {
				super.unregister();
				if (_9_3_0308355687 != null) _9_3_0308355687.unregister();
				if (_10_3_0687123240 != null) _10_3_0687123240.unregister();
				if (_19_3_1730637905 != null) _19_3_1730637905.unregister();
			}

			public class _9_3_0308355687 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _9_3_0308355687(B box) {
					super(box);
					_value("No facets");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
					super.unregister();
				}
			}

			public class _10_3_0687123240 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public SearchBoxExamplesMold._7_1_1484719442._8_2_0351473557._10_3_0687123240. SearchBox1 searchBox1;
				public SearchBoxExamplesMold._7_1_1484719442._8_2_0351473557._10_3_0687123240. List1 list1;

				public _10_3_0687123240(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (searchBox1 == null) searchBox1 = register(new SearchBox1(box()).<SearchBox1>id("a_1182136866").owner(AbstractSearchBoxExamplesMold.this));
					if (list1 == null) list1 = register(new List1(box()).<List1>id("a819653891").owner(AbstractSearchBoxExamplesMold.this));
				}

				@Override
				public void unregister() {
					super.unregister();
					if (searchBox1 != null) searchBox1.unregister();
					if (list1 != null) list1.unregister();
				}

				public class SearchBox1 extends io.intino.alexandria.ui.displays.components.SearchBox<io.intino.alexandria.ui.displays.notifiers.SearchBoxNotifier, B>  {

					public SearchBox1(B box) {
						super(box);
						label("female population");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
						super.unregister();
					}
				}

				public class List1 extends io.intino.alexandria.ui.displays.components.List<B, SearchBox1Mold, io.intino.alexandria.ui.documentation.Person>  {

					public List1(B box) {
						super(box);

						_pageSize(20);
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
						super.unregister();
					}

					public SearchBox1Mold create(io.intino.alexandria.ui.documentation.Person element) {
						SearchBox1Mold result = new SearchBox1Mold((UiFrameworkBox)box());
						result.id(java.util.UUID.randomUUID().toString());
						result.item(element);
						return result;
					}
				}
			}

			public class _19_3_1730637905 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public SearchBoxExamplesMold._7_1_1484719442._8_2_0351473557._19_3_1730637905. _19_11_1716687082 _19_11_1716687082;

				public _19_3_1730637905(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_19_11_1716687082 == null) _19_11_1716687082 = register(new _19_11_1716687082(box()).<_19_11_1716687082>id("a_1325868256").owner(AbstractSearchBoxExamplesMold.this));
				}

				@Override
				public void unregister() {
					super.unregister();
					if (_19_11_1716687082 != null) _19_11_1716687082.unregister();
				}

				public class _19_11_1716687082 extends io.intino.alexandria.ui.displays.components.TextCode<io.intino.alexandria.ui.displays.notifiers.TextCodeNotifier, B>  {

					public _19_11_1716687082(B box) {
						super(box);
						_value("SearchBox(collections=list,placeholder=\"filter elements...\") searchBoxList(itemClass=\"io.intino.alexandria.ui.documentation.Person\") list<br/>&nbsp;&nbsp;&nbsp;&nbsp;Mold > Item(height=60px,width=30%) sortingMold<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Text firstName<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Block(layout=Horizontal, spacing=DP16)<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Text(format=description) gender<br/>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Text(format=description) age as Labeled(\"age\")");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
						super.unregister();
					}
				}
			}
		}
	}
}
